//
//  OverrideNavigationController.m
//  AdaptiveLayout
//
//  Created by Gene Whitaker on 9/11/14.
//  Copyright (c) 2014 Bombing Brain Interactive. All rights reserved.
//

#import "OverrideNavigationController.h"

@interface OverrideNavigationController ()

@end

@implementation OverrideNavigationController

//The following methods override the size class of OverrideViewController - comment these 3 methods out and view "Complex Adaptive Layout" to see the difference when not in use

-(void)viewWillLayoutSubviews {
        [self setCustomLayoutForSize:self.view.frame.size];
}

-(void)viewWillTransitionToSize:(CGSize)size withTransitionCoordinator:(id<UIViewControllerTransitionCoordinator>)coordinator {
    [self setCustomLayoutForSize:size];
}

-(void)setCustomLayoutForSize:(CGSize)size {
    
    if (self.traitCollection.horizontalSizeClass == UIUserInterfaceSizeClassCompact ||
        self.traitCollection.verticalSizeClass == UIUserInterfaceSizeClassCompact) {
        
        //Force the size class to "compact, compact" if this is a compact device in landscape (iPhone)
        //This prevents the Iphone 6+ from showing the "setlist/notes" view
        UITraitCollection *customCollection = [UITraitCollection traitCollectionWithHorizontalSizeClass:UIUserInterfaceSizeClassCompact];
        UITraitCollection *combinedTraits = [UITraitCollection traitCollectionWithTraitsFromCollections:@[self.traitCollection, customCollection]];
        [self setOverrideTraitCollection:combinedTraits forChildViewController:self.topViewController];
        
    }
    else {
    
        UITraitCollection *customCollection;
        if (size.width > size.height) {
            //Customize the size class to "regular, compact" if this is a large device in landscape (iPad)
            //This facilitated the different size classes implemented for the iPad and forces the OverrideViewController to use Regular width,Compact height in landscape
            customCollection = [UITraitCollection traitCollectionWithVerticalSizeClass:UIUserInterfaceSizeClassCompact];
        }
        else {
            customCollection = [UITraitCollection traitCollectionWithVerticalSizeClass:UIUserInterfaceSizeClassRegular];
        }
        UITraitCollection *combinedTraits = [UITraitCollection traitCollectionWithTraitsFromCollections:@[self.traitCollection, customCollection]];
        [self setOverrideTraitCollection:combinedTraits forChildViewController:self.topViewController];
        
    }

}

@end
