//
//  RootTableViewController.m
//  AdaptiveLayout
//
//  Created by Gene Whitaker on 9/10/14.
//  Copyright (c) 2014 Bombing Brain Interactive. All rights reserved.
//

#import "RootTableViewController.h"
#import "RootTableViewCell.h"
#import "OverrideViewController.h"

@interface RootTableViewController () <OverrideViewControllerDelegate,UIPopoverPresentationControllerDelegate>
@property(strong, nonatomic) NSArray *items;
@end

@implementation RootTableViewController

-(NSArray*)items {
    if(!_items) {
        //Generate some data for the table view - FOR DEMO ONLY, don't ever do it this way!
        _items = @[
                   @[@"Adaptive Layout Sample", @"Example of simple adaptive layout in views and text objects.",@"BasiceSegue"],
                   @[@"Complex Adaptive Layout", @"Complex layout overrides trait collection of child view controllers for iPad.",@"OverrideSegue"],
                   ];
    }
    return _items;
}

- (void)viewDidLoad {
    [super viewDidLoad];
    self.clearsSelectionOnViewWillAppear = NO;
}

 #pragma mark - Navigation

 - (void)prepareForSegue:(UIStoryboardSegue *)segue sender:(id)sender {
     if ([segue.identifier isEqualToString:@"OverrideSegue"]) {
         UINavigationController *nvc = (UINavigationController*)[segue destinationViewController];
         OverrideViewController *ovc = (OverrideViewController*)nvc.topViewController;
         ovc.delegate = self;
     }
     else if ([segue.identifier isEqualToString:@"InfoSegue"]) {
         UIViewController *vc = (UIViewController*)[segue destinationViewController];
         UIPopoverPresentationController *popPC = vc.popoverPresentationController;
         popPC.delegate = self;
         vc.navigationItem.rightBarButtonItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemDone target:self action:@selector(closeProfile:)];
     }

 }


- (void)closeProfile:(id)sender {
    [self dismissViewControllerAnimated:YES completion:NULL];
}

#pragma mark - UIPopoverPresentationControllerDelegate methods

-(UIModalPresentationStyle)adaptivePresentationStyleForPresentationController:(UIPresentationController *)controller {
    return UIModalPresentationFullScreen;
}

-(UIViewController*)presentationController:(UIPresentationController *)controller viewControllerForAdaptivePresentationStyle:(UIModalPresentationStyle)style {
    UINavigationController *navController = [[UINavigationController alloc] initWithRootViewController:controller.presentedViewController];
    return navController;
}


#pragma mark - Table view datasource/delegate methods


- (NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    // Return the number of rows in the section.
    return self.items.count;
}


- (UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    RootTableViewCell *cell = [tableView dequeueReusableCellWithIdentifier:@"RootTableViewCell" forIndexPath:indexPath];
    
    //FOR DEMO ONLY, don't ever do it this way!
    NSArray *item = self.items[indexPath.row];
    cell.titleLabel.text = item[0];
    cell.descLabel.text = item[1];
    
    return cell;
}

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    //FOR DEMO ONLY, don't ever do it this way!
    NSArray *item = self.items[indexPath.row];
    NSString *segueIdentifier = item[2];
    [self performSegueWithIdentifier:segueIdentifier sender:self];
}



#pragma mark - OverrideViewControllerDelegate

-(void)overrideViewControllerDone {
    [self dismissViewControllerAnimated:YES completion:nil];
}

@end
